changeset 15098:a3c8776451ce

Comment change.
author Richard M. Stallman <rms@gnu.org>
date Sat, 27 Apr 1996 02:09:56 +0000
parents 32c26cb9e078
children 857388330750
files src/frame.h
diffstat 1 files changed, 5 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/frame.h	Sat Apr 27 01:14:17 1996 +0000
+++ b/src/frame.h	Sat Apr 27 02:09:56 1996 +0000
@@ -106,9 +106,11 @@
   Lisp_Object scroll_bars;
   Lisp_Object condemned_scroll_bars;
 
-  /* List of elements to display in the menu bar.
-     The elements have the form (KEY STRING . nil) to start;
-     when they are displayed, the hpos of the left edge goes in the cddr.  */
+  /* Vector describing the items to display in the menu bar.
+     Each item has four elements in this vector.
+     They are KEY, STRING, SUBMAP, and HPOS.
+     (HPOS is not used in when the X toolkit is in use.)
+     There are four additional elements of nil at the end, to terminate.  */
   Lisp_Object menu_bar_items;
 
   /* Alist of elements (FACE-NAME . FACE-VECTOR-DATA).  */